Module: Bulldogger::FramesCollector

Defined in:
lib/bulldogger/frames_collector.rb

Overview

Streams structural events for test windows in the current process. It does not capture values or control test execution.

Constant Summary collapse

EVENTS =
%i[call b_call return b_return raise].freeze
COLLECTOR_DIR =
File.expand_path(__dir__)

Class Method Summary collapse

Class Method Details

.active?Boolean

Returns:

  • (Boolean)


38
39
40
# File 'lib/bulldogger/frames_collector.rb', line 38

def active?
  @active == true
end

.begin_testObject



26
27
28
29
30
31
# File 'lib/bulldogger/frames_collector.rb', line 26

def begin_test
  @active = true
  @raise_ordinal = 0
  @counts = Hash.new(0)
  @stack = []
end

.end_testObject



33
34
35
36
# File 'lib/bulldogger/frames_collector.rb', line 33

def end_test
  @active = false
  @stack = []
end